require "td_model/version"
require "td_model/base"
require "td_model/sql"
require "td_model/errors/failed_to_type_validation_of_column_error"
require "singleton"

module TdModel
  class Configuration
    include Singleton

    def self.defaults
      @defaults ||= {
          :database_name => nil,
          :api_key => nil,
          :auto_create_table => true,
          :td_client => nil,
      }
    end

    def initialize
      self.class.defaults.each_pair { |k, v| send("#{k}=", v) }
    end

    def init_logger
      TreasureData::Logger.open(database_name,
                                :apikey => api_key,
                                :auto_create_table => auto_create_table)
    end

    def init_td_client
      self.td_client = TreasureData::Client.new(ENV['TD_API_KEY'])
    end

    attr_accessor :database_name, :api_key, :auto_create_table, :td_client
  end

  def self.config
    Configuration.instance
  end

  def self.configure
    yield config
    config.init_logger
    config.init_td_client
  end
end
